import 'package:flutter/material.dart';
import 'package:tivio_sdk/tivio.dart';

class StreamTestPage extends StatelessWidget {
  final Tivio _tivio;

  StreamTestPage(this._tivio);

  subscribeToData() async {
    /// Widget

    print('subscribeToWidget');
    var widgetStream = _tivio.subscribeToWidget(widgetId: 'FlutterDemo');

    widgetStream.stream.listen((event) {
      print('subscribeToWidget 1 name: ${event.name}');
    });

    await Future.delayed(Duration(seconds: 1));
    widgetStream.close();
    print('close subscribeToWidget');

    /// Videos

    print('subscribeToVideosInSection');
    var videosStream = _tivio.subscribeToVideosInSection(sectionId: 'Lhkb2QD0Sqg40InUPzfy');
    videosStream.stream.listen((event) {
      print('subscribeToVideosInSection records length: ${event.records.length}');
      event.records.forEach((element) {
        print('subscribeToVideosInSection name: ${element.name}');
      });
    });

    print('subscribeToVideosInSection 2');
    var videosStream2 = _tivio.subscribeToVideosInSection(sectionId: 'yxXF7aNGgzJpAfCF99Ss');
    videosStream2.stream.listen((event) {
      print('subscribeToVideosInSection 2 records length: ${event.records.length}');
      event.records.forEach((element) {
        print('subscribeToVideosInSection 2 name: ${element.name}');
      });
    });

    await Future.delayed(Duration(seconds: 1));

    _tivio.fetchNextVideosInSection(sectionId: 'Lhkb2QD0Sqg40InUPzfy');
    _tivio.fetchNextVideosInSection(sectionId: 'yxXF7aNGgzJpAfCF99Ss');

    await Future.delayed(Duration(seconds: 1));

    videosStream.close();
    videosStream2.close();

    /// Recents

    print('subscribeRecentVideosInWidget');
    var widgetRecentStream = _tivio.subscribeToRecentVideosInWidget(widgetId: 'FlutterDemo');
    widgetRecentStream.stream.listen((event) {
      print('widget recent length: ${event.records.length}');
      event.records.forEach((element) {
        print('widget recent: ${element.name}');
      });
    });

    print('subscribeRecentVideosInChannel');
    var channelRecentStream = _tivio.subscribeToRecentVideosInChannel(channelId: 'LzqDUHWGqEPUn6LcEjYN');
    channelRecentStream.stream.listen((event) {
      print('channel recent length: ${event.records.length}');
      event.records.forEach((element) {
        print('channel recent: ${element.name}');
      });
    });

    await Future.delayed(Duration(seconds: 2));
    print('close subscribeRecentVideosInWidget');
    print('close subscribeRecentVideosInChannel');

    widgetRecentStream.close();
    channelRecentStream.close();
  }

  @override
  Widget build(BuildContext context) {
    subscribeToData();

    return Scaffold(
      appBar: AppBar(
        title: Text('Stream test page'),
      ),
    );
  }
}
