library tivio;
import 'package:meta/meta.dart';
import 'dart:async';
import 'bridge.dart';
import 'dto.dart';
import 'player/tivio_player_wrapper.dart';
import 'utils/enum.dart';
import 'streams.dart';
export 'dto.dart';
export 'player/tivio_player.dart';
export 'player/tivio_player_controller.dart';
export 'player/tivio_player_input_source.dart';
export 'player/tivio_player_wrapper.dart';
export 'streams.dart';

enum TivioLanguages {
  cs,
  en,
  sk,
  de,
  pl,
}

class Tivio {
  final String _appId;
  final TivioLanguages _language;
  final bool _development;
  final Bridge _bridge = Bridge();

  Tivio(this._appId, this._language, this._development);

  Future<Tivio> init() async {
    await _bridge.init(_appId, enumToString(_language), this._development);
    return this;
  }

  setLanguage(TivioLanguages language) => _bridge.setLanguage(enumToString(language));

  Future<TivioPlayerWrapper> getPlayer(String id) => _bridge.getPlayer(id);

  Future<void> setUser(String userId, dynamic payload) async => null;

  /// API 1.0.0

  /// Widget

  TivioDataStream<TivioDataWidget> subscribeToWidget({@required String widgetId, int count = 10}) {
    return _bridge.subscribeToWidget(widgetId: widgetId, count: count);
  }

  /// Channel

  TivioDataStream<TivioDataPagination<TivioDataChannel>> subscribeToChannelsInWidget({@required String widgetId, int count = 10}) {
    return _bridge.subscribeToChannelsInWidget(widgetId: widgetId, count: count);
  }

  fetchNextChannelsInWidget({@required String widgetId, int count = 10}) {
    return _bridge.fetchNextChannelsInWidget();
  }

  TivioDataStream<TivioDataChannel> subscribeToChannel({@required String channelId}) {
    return _bridge.subscribeToChannel(channelId: channelId);
  }

  /// Section

  TivioDataStream<TivioDataPagination<TivioDataSection>> subscribeToSectionsInChannel({@required String channelId, int count = 10}) {
    return _bridge.subscribeToSectionsInChannel(channelId: channelId, count: count);
  }

  fetchNextSectionsInChannel({@required String channelId, int count = 10}) {
    return _bridge.fetchNextSectionsInChannel(channelId: channelId, count: count);
  }

  TivioDataStream<TivioDataSection> subscribeToSection({@required String sectionId}) {
    return _bridge.subscribeToSection(sectionId: sectionId);
  }

  /// Video

  TivioDataStream<TivioDataPagination<TivioDataVideo>> subscribeToVideosInSection ({@required String sectionId, int count = 10}) {
    return _bridge.subscribeToVideosInSection(sectionId: sectionId, count: count);
  }

  fetchNextVideosInSection({@required String sectionId, int count = 10}) {
    return _bridge.fetchNextVideosInSection(sectionId: sectionId, count: count);
  }

  TivioDataStream<TivioDataVideo> subscribeToVideo({@required String videoId}) {
    return _bridge.subscribeToVideo(videoId: videoId);
  }

  /// Recent

  TivioDataStream<TivioDataPagination<TivioDataVideo>> subscribeToRecentVideosInWidget({@required String widgetId, int count = 10}) {
    return _bridge.subscribeToRecentVideosInWidget(widgetId: widgetId, count: count);
  }

  TivioDataStream<TivioDataPagination<TivioDataVideo>> subscribeToRecentVideosInChannel({@required String channelId, int count = 10}) {
    return _bridge.subscribeToRecentVideosInChannel(channelId: channelId, count: count);
  }

  /// Search

  Future<TivioDataPagination<TivioDataChannel>> searchChannels({@required String query, int limit = 10}) {
    return _bridge.searchChannels(query, limit);
  }

  Future<TivioDataPagination<TivioDataVideo>> searchVideos({@required String query, int limit = 10}) {
    return _bridge.searchVideos(query, limit);
  }
}

Future<Tivio> initTivio({String secret, TivioLanguages language, bool development = false}) {
  return Tivio(secret, language, development).init();
}
